@@ -165,7 +165,7 @@ class Classifier(BaseLearner):
                 # clf = clf.fit(X_train, y_train)
                 self.logger.info("Calibrating probabilities")
                 calibrated_clf = CalibratedClassifierCV(base_estimator=clf, method='sigmoid',
-                                                        cv=3, ensemble=False, n_jobs=-1)
+                                                        cv=3, ensemble=False, n_jobs=None)
                 calibrated_clf.fit(X_train, y_train)
 
                 y_pred = calibrated_clf.predict_proba(X_test)
