@@ -1,3 +1,5 @@
+from statistics import harmonic_mean
+
 import numpy as np
 
 
@@ -41,10 +43,10 @@ def loss_threshold(n_classes: int, metric='logloss', eps=1e-3):
 
     if metric == 'logloss':
         lower_bound = logloss(np.array([[1, 0]]), np.array([[0.5, 0.5]]))[0]
-        m = (logloss(y_true=c, y_pred=p)[0] + lower_bound) / 2
+        m = harmonic_mean([logloss(y_true=c, y_pred=p)[0], lower_bound])
     elif metric == 'brier':
         lower_bound = brier(np.array([[1, 0]]), np.array([[0.5, 0.5]]))[0]
-        m = (brier(y_true=c, y_pred=p)[0] + lower_bound) / 2
+        m = harmonic_mean([brier(y_true=c, y_pred=p)[0], lower_bound])
     else:
         raise ValueError(f"Unsupported metric '{metric}'.")
 
